<?php

namespace App\Models\Traits;

use Illuminate\Database\Eloquent\Casts\Attribute;

trait FormattedPhoneTrait
{
    /**
     * Format a phone number to be human readable.
     *
     * @package Namespace\App\Contact
     * @since   1.0.0
     *
     * @return void
     */
    protected function phoneNumber(): Attribute
    {
        return Attribute::make(
            get: function (mixed $value, array $attributes) {
                $phoneLength = strlen($attributes['phone_number']);
                $phoneNumber = preg_replace('/[^0-9]/', '', $attributes['phone_number']);

                if ($phoneLength > 10) {
                    $countryCode = substr($phoneNumber, 0, $phoneLength - 10);
                    $areaCode = substr($phoneNumber, -10, 3);
                    $nextThree = substr($phoneNumber, -7, 3);
                    $lastFour = substr($phoneNumber, -4, 4);

                    $phoneNumber = "({$areaCode}) {$nextThree}-{$lastFour}";
                } elseif ($phoneLength == 10) {
                    $areaCode = substr($phoneNumber, 0, 3);
                    $nextThree = substr($phoneNumber, 3, 3);
                    $lastFour = substr($phoneNumber, 6, 4);

                    $phoneNumber = "({$areaCode}) {$nextThree}-{$lastFour}";
                } elseif ($phoneLength == 7) {
                    $nextThree = substr($phoneNumber, 0, 3);
                    $lastFour = substr($phoneNumber, 3, 4);

                    $phoneNumber = "{$nextThree}-{$lastFour}";
                }

                return $phoneNumber;
            },
            set: function (mixed $value) {
                return preg_replace('/[^0-9]/', '', $value);
            },
        );
    }
}
